import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Pagination from './Pagination';
import Search from './Search';
import '../.././datagrid.css';
import GridExport from './GridExport';

/*
*  The TableDrawer component for the grid which will render - renderPagination, FaArrowLeft, FaArrowRight and Search.
 * It will also handle the onPageDecrement, onPageIncrement and pagination functionality for the grid.
 * @type {class}
*/

class TableDrawer extends Component {
  constructor(props) {
    super(props);
    this.onSort = this.onSort.bind(this);
  }
  onSort(columnId) {
    this.props.onSort(columnId);
  }

  render() {
    return (
      <div className="total-record-row" style={this.props.styles.gridTableRow}>
        <div className="wrapper-pagination-search">
          <Pagination
            data={this.props.data}
            onPagination={this.props.onPagination}
            currentPage={this.props.currentPage}
            recordsPerPage={this.props.recordsPerPage}
          />
          <Search
            metaData={this.props.metaData}
            onSearch={this.props.onSearch}
          />
        </div>
        <div className="grid-export">
          <button className="clearFilterButton" onClick={this.props.handleReRenderButtonClick}> Clear </button>
          <GridExport metaData={this.props.metaData} data={this.props.data} />
        </div>
      </div>
    );
  }
}

TableDrawer.propTypes = {
  handleReRenderButtonClick: PropTypes.func.isRequired,
  data: PropTypes.array,
  metaData: PropTypes.object,
  styles: PropTypes.object,
  onPagination: PropTypes.func.isRequired,
  onSort: PropTypes.func.isRequired,
  onSearch: PropTypes.func.isRequired,
  currentPage: PropTypes.number,
  recordsPerPage: PropTypes.number,
};

TableDrawer.defaultProps = {
  data: [],
  metaData: {},
  styles: {},
  currentPage: 0,
  recordsPerPage: 0,
};

export default TableDrawer;
